<?php
require "connect.php";

$response = array();
$response['success'] = 0;

try {
    // Check if store_id parameter is provided
    if (!isset($_GET['store_id'])) {
        throw new Exception('Missing store_id parameter');
    }

    // Get store_id from URL parameter
    $store_id = $_GET['store_id'];

    // Get today's date
    $today = date('Y-m-d');

    // Get the first day of the current month
    $first_day_of_month = date('Y-m-01');
    
    
    // Fetch today's sales for the specified store
    $sales_query = "SELECT SUM(total_price) AS total_sales FROM sales WHERE DATE(created_at) = ? AND store_id = ?";
    $sales_stmt = mysqli_prepare($con, $sales_query);
    mysqli_stmt_bind_param($sales_stmt, "ss", $today, $store_id);
    mysqli_stmt_execute($sales_stmt);
    $sales_result = mysqli_stmt_get_result($sales_stmt);

    if ($sales_result && mysqli_num_rows($sales_result) > 0) {
        $row_sales = mysqli_fetch_assoc($sales_result);
        $response['today_sales'] = (float)$row_sales['total_sales'];
    } else {
        $response['today_sales'] = 0.0;
    }

    // Fetch today's expenses for the specified store
    $expenses_query = "SELECT SUM(price) AS total_expenses FROM expenses WHERE DATE(created_at) = ? AND store_id = ?";
    $expenses_stmt = mysqli_prepare($con, $expenses_query);
    mysqli_stmt_bind_param($expenses_stmt, "ss", $today, $store_id);
    mysqli_stmt_execute($expenses_stmt);
    $expenses_result = mysqli_stmt_get_result($expenses_stmt);

    if ($expenses_result && mysqli_num_rows($expenses_result) > 0) {
        $row_expenses = mysqli_fetch_assoc($expenses_result);
        $response['today_expenses'] = (float)$row_expenses['total_expenses'];
    } else {
        $response['today_expenses'] = 0.0;
    }

    // Calculate today's income for the specified store
    $response['today_income'] = $response['today_sales'] - $response['today_expenses'];

    // Fetch total sales for the current month for the specified store
    $monthly_sales_query = "SELECT SUM(total_price) AS total_sales FROM sales WHERE created_at >= ? AND store_id = ?";
    $monthly_sales_stmt = mysqli_prepare($con, $monthly_sales_query);
    mysqli_stmt_bind_param($monthly_sales_stmt, "ss", $first_day_of_month, $store_id);
    mysqli_stmt_execute($monthly_sales_stmt);
    $monthly_sales_result = mysqli_stmt_get_result($monthly_sales_stmt);

    // Fetch total expenses for the current month for the specified store
    $monthly_expenses_query = "SELECT SUM(price) AS total_expenses FROM expenses WHERE DATE(created_at) >= ? AND store_id = ?";
    $monthly_expenses_stmt = mysqli_prepare($con, $monthly_expenses_query);
    mysqli_stmt_bind_param($monthly_expenses_stmt, "ss", $first_day_of_month, $store_id);
    mysqli_stmt_execute($monthly_expenses_stmt);
    $monthly_expenses_result = mysqli_stmt_get_result($monthly_expenses_stmt);

    // Calculate monthly income
    if ($monthly_sales_result && $monthly_expenses_result) {
        $row_monthly_sales = mysqli_fetch_assoc($monthly_sales_result);
        $row_monthly_expenses = mysqli_fetch_assoc($monthly_expenses_result);

        $monthly_sales = (float)$row_monthly_sales['total_sales'];
        $monthly_expenses = (float)$row_monthly_expenses['total_expenses'];

        // Calculate monthly income (sales - expenses)
        $monthly_income = $monthly_sales - $monthly_expenses;

        $response['monthly_income'] = $monthly_income;
        $response['success'] = 1;
    } else {
        // If no data available for the current month, set monthly income to 0
        $response['monthly_income'] = 0.0;
        $response['success'] = 1;
    }

    echo json_encode($response);
} catch (Exception $e) {
    // Handle any exceptions or errors
    $response['message'] = 'Error: ' . $e->getMessage();
    echo json_encode($response);
}

mysqli_close($con);
?>



