<?php

require "../connect.php";

// Check if request method is POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve input data
    $expense_name = $_POST["expense_name"]; // Retrieve the expense name from POST data

    // Validate input data
    if (!empty($expense_name)) {
        // Prepare the SELECT statement to retrieve ID based on the name
        $select_query = "SELECT id FROM expenses WHERE name = ?";
        $stmt = mysqli_prepare($con, $select_query);

        // Bind parameters to the prepared statement
        mysqli_stmt_bind_param($stmt, "s", $expense_name);

        // Execute the statement
        if (mysqli_stmt_execute($stmt)) {
            // Bind the result variable
            mysqli_stmt_bind_result($stmt, $expense_id);

            // Fetch the result (should be only one row)
            if (mysqli_stmt_fetch($stmt)) {
                // Now we have the expense ID, proceed with DELETE operation
                $delete_query = "DELETE FROM expenses WHERE id = ?";
                $stmt_delete = mysqli_prepare($con, $delete_query);

                // Bind parameters to the prepared DELETE statement
                mysqli_stmt_bind_param($stmt_delete, "i", $expense_id);

                // Execute the DELETE statement
                if (mysqli_stmt_execute($stmt_delete)) {
                    // Check if any rows were affected
                    if (mysqli_stmt_affected_rows($stmt_delete) > 0) {
                        // Success response
                        $response['success'] = true;
                        $response['message'] = "Expense deleted successfully";
                    } else {
                        // No rows affected, possibly expense ID not found
                        $response['success'] = false;
                        $response['message'] = "Expense ID not found";
                    }
                } else {
                    // Error response for DELETE operation
                    $response['success'] = false;
                    $response['message'] = "Error: " . mysqli_stmt_error($stmt_delete);
                }

                // Close the DELETE statement
                mysqli_stmt_close($stmt_delete);
            } else {
                // Expense with the given name not found
                $response['success'] = false;
                $response['message'] = "Expense not found with the given name";
            }
        } else {
            // Error response for SELECT operation
            $response['success'] = false;
            $response['message'] = "Error: " . mysqli_stmt_error($stmt);
        }

        // Close the SELECT statement
        mysqli_stmt_close($stmt);
    } else {
        // Invalid input response
        $response['success'] = false;
        $response['message'] = "Invalid input data";
    }
} else {
    // Invalid request method response
    $response['success'] = false;
    $response['message'] = "Invalid request method";
}

// Return JSON response
echo json_encode($response);

// Close database connection
mysqli_close($con);

?>
