<?php

// Include connection file
require "connect.php";

$flag['success'] = 0;
$flag['data'] = array();
$store_id = $_GET['store_id'] ?? '';

// Check if store_id parameter is provided
if (empty($store_id)) {
    $flag['success'] = false;
    $flag['message'] = 'Error: Missing store_id parameter';
    echo json_encode($flag);
    exit;
}


// Select query to fetch stock data where quantity is less than or equal to minimum quantity for a specific store
$select_query = "SELECT name, description, quantity FROM stock WHERE quantity <= min_quantity AND store_id = ?";

// Prepare the select query
$stmt = mysqli_prepare($con, $select_query);

if ($stmt) {
    // Bind the store_id parameter to the prepared statement
    mysqli_stmt_bind_param($stmt, "s", $store_id);
    
    // Execute the query
    mysqli_stmt_execute($stmt);
    
    // Bind result variables
    mysqli_stmt_bind_result($stmt, $name, $description, $quantity);
    
    // Fetch results and store in response array
    while (mysqli_stmt_fetch($stmt)) {
        $stock_item = array(
            'name' => $name,
            'description' => $description,
            'quantity' => $quantity
        );
        $flag['data'][] = $stock_item;
    }
    
    // Close statement
    mysqli_stmt_close($stmt);
} else {
    // If prepared statement creation failed, set error message
    $flag['success'] = false;
    $flag['message'] = "Error: " . mysqli_error($con);
}

// Send response as JSON
echo json_encode($flag);

// Close connection
mysqli_close($con);

?>

